Stats
-------

Utilities
^^^^^^^^^^^^^^^^
*correlation()*
""""""""""""""""
.. autofunction:: neurokit2.cor

*density()*
""""""""""""
.. autofunction:: neurokit2.density

*distance()*
""""""""""""""
.. autofunction:: neurokit2.distance

*hdi()*
""""""""""""
.. autofunction:: neurokit2.hdi

*mad()*
""""""""""""
.. autofunction:: neurokit2.mad

*rescale()*
""""""""""""
.. autofunction:: neurokit2.rescale

*standardize()*
""""""""""""""""
.. autofunction:: neurokit2.standardize

*summary()*
""""""""""""
.. autofunction:: neurokit2.summary_plot


Clustering
^^^^^^^^^^^^^^^^
*cluster()*
""""""""""""
.. autofunction:: neurokit2.cluster

*cluster_findnumber()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.cluster_findnumber

*cluster_quality()*
""""""""""""""""""""
.. autofunction:: neurokit2.cluster_quality


Indices of fit
^^^^^^^^^^^^^^^^
*fit_error()*
""""""""""""""
.. autofunction:: neurokit2.fit_error

*fit_loess()*
""""""""""""""
.. autofunction:: neurokit2.fit_loess

*fit_mixture()*
""""""""""""""""
.. autofunction:: neurokit2.fit_mixture

*fit_polynomial()*
""""""""""""""""""""
.. autofunction:: neurokit2.fit_polynomial


*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*

.. automodule:: neurokit2.stats
   :members:
   :exclude-members: cor, density, distance, hdi, mad, rescale, standardize, summary_plot, cluster, cluster_findnumber, cluster_quality, fit_error, fit_loess, fit_mixture, fit_polynomial